@@ -16,6 +16,7 @@ import shutil
 import traceback
 # from pathlib import Path
 
+import utils.dir as dirUtils
 import utils.objectUtils as obj
 import utils.file_read as read
 import utils.file_write as write
@@ -442,7 +443,8 @@ def _copy_files_from_array(file_list, ftp=None, attempted_delete=False):
     for file in file_list:
         try:
             if ftp is not None:
-                ftp.makedirs(os.path.dirname(file['dst_path']))
+                dirUtils.create(os.path.dirname(file['dst_path']), False, ftp)
+                # ftp.makedirs(os.path.dirname(file['dst_path']))
                 ftp.upload_if_newer(file['src_path'], file['dst_path'])
                 continue
 
